# CHANGELOG



## v1.1.0 (2024-02-10)

### Feature

* feat(#98): add unique (#108)

Fixes #98 ([`71de249`](https://github.com/MartinBernstorff/iterpy/commit/71de24909611f98cf7e088d447bb1333bd40fa85))

* feat(#98): add unique

Fixes #98 ([`7cae674`](https://github.com/MartinBernstorff/iterpy/commit/7cae6741f51b7c2f8fabf4a8f7162a2109bbe8a4))


## v1.0.0 (2024-02-10)

### Breaking

* fix!: clarify public api (#107) ([`95e7912`](https://github.com/MartinBernstorff/iterpy/commit/95e791270ca2c9de61f1843a3daaa0f096023389))

* fix!: clarify public api ([`cfba4ce`](https://github.com/MartinBernstorff/iterpy/commit/cfba4ce098e0d0aed426c9dedd842441f6661b88))

### Ci

* ci: add codspeed benchmarking (#105) ([`91d78bc`](https://github.com/MartinBernstorff/iterpy/commit/91d78bc98e063be852011a8b2667fe4b3f76248f))

* ci: add codspeed benchmarking ([`d5e9219`](https://github.com/MartinBernstorff/iterpy/commit/d5e92197e3a4dbf3f6a01b78c18481d648e7a6ef))

### Unknown

* Update README.md ([`b5ac759`](https://github.com/MartinBernstorff/iterpy/commit/b5ac759801136f15c5bddc5ae5b334e429c9a029))

* Update README.md ([`06856da`](https://github.com/MartinBernstorff/iterpy/commit/06856da9cccb88a322a4c12efd1c6e033ffd6dd8))


## v0.23.0 (2024-02-10)

### Feature

* feat(#97): tail and head (#104)

Fixes #97 ([`32a407d`](https://github.com/MartinBernstorff/iterpy/commit/32a407d20df542df68d09555fc5e199d9ba2b353))

* feat(#97): tail and head

Fixes #97 ([`4a1b977`](https://github.com/MartinBernstorff/iterpy/commit/4a1b9777e14331f861a360e19b44c5a7150cd2d7))


## v0.22.2 (2024-02-10)

### Fix

* fix(#102): recursive consume bug introduced in 0.22.1 (#103)

Fixes #102 ([`849cd5e`](https://github.com/MartinBernstorff/iterpy/commit/849cd5e8e827593758fc5fed9bcf7478e2f88bdd))

* fix(#102): recursive consume bug introduced in 0.22.1

Fixes #102 ([`5e8087b`](https://github.com/MartinBernstorff/iterpy/commit/5e8087ba3445567402e557b46f3624d5ff82f582))

### Unknown

* deps:(deps-dev): bump pytest-sugar from 0.9.7 to 1.0.0 (#99) ([`cded803`](https://github.com/MartinBernstorff/iterpy/commit/cded80336b9bb2458cfe3a8dbc4decf191ddac49))

* deps:(deps-dev): bump ruff from 0.1.14 to 0.2.0 (#100) ([`f72c71f`](https://github.com/MartinBernstorff/iterpy/commit/f72c71fea1777ea6e0b6f22144f7c1f5e946e7ca))

* deps:(deps-dev): bump ruff from 0.1.14 to 0.2.0

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.14 to 0.2.0.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.14...v0.2.0)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`4bac6e3`](https://github.com/MartinBernstorff/iterpy/commit/4bac6e3312f5305b443adf5b3c5cead425b47629))

* deps:(deps-dev): bump pytest-sugar from 0.9.7 to 1.0.0

Bumps [pytest-sugar](https://github.com/Teemu/pytest-sugar) from 0.9.7 to 1.0.0.
- [Release notes](https://github.com/Teemu/pytest-sugar/releases)
- [Changelog](https://github.com/Teemu/pytest-sugar/blob/main/CHANGES.rst)
- [Commits](https://github.com/Teemu/pytest-sugar/compare/v0.9.7...v1.0.0)

---
updated-dependencies:
- dependency-name: pytest-sugar
  dependency-type: direct:production
  update-type: version-update:semver-major
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`1cf5e05`](https://github.com/MartinBernstorff/iterpy/commit/1cf5e05ba1f781f2e442fcfb8843d1ffcff8804e))

* deps:(deps-dev): bump pyright from 1.1.348 to 1.1.349 (#95) ([`8f5d853`](https://github.com/MartinBernstorff/iterpy/commit/8f5d853d18755e8af86f5c357498baaeb32c61dd))

* deps:(deps-dev): bump pyright from 1.1.348 to 1.1.349

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.348 to 1.1.349.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.348...v1.1.349)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`94fbc8d`](https://github.com/MartinBernstorff/iterpy/commit/94fbc8d98b18f7e63b9b63db0f4cd9877c85b696))

* deps:(deps-dev): bump pytest from 7.4.4 to 8.0.0 (#96) ([`4e4ca5e`](https://github.com/MartinBernstorff/iterpy/commit/4e4ca5e8b3f7df41d06e566bf192380932b9fdd5))

* deps:(deps-dev): bump pytest from 7.4.4 to 8.0.0

Bumps [pytest](https://github.com/pytest-dev/pytest) from 7.4.4 to 8.0.0.
- [Release notes](https://github.com/pytest-dev/pytest/releases)
- [Changelog](https://github.com/pytest-dev/pytest/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest/compare/7.4.4...8.0.0)

---
updated-dependencies:
- dependency-name: pytest
  dependency-type: direct:production
  update-type: version-update:semver-major
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`526c3d1`](https://github.com/MartinBernstorff/iterpy/commit/526c3d18f2fb5733bdde5428cf41364f2dff31ff))


## v0.22.1 (2024-01-23)

### Build

* build(deps): update test_iter.py and pyproject.toml ([`bebc22c`](https://github.com/MartinBernstorff/iterpy/commit/bebc22c26b1c339e9874941958317bc7ad031e05))

### Chore

* chore: update devcontainer.json ([`968cf03`](https://github.com/MartinBernstorff/iterpy/commit/968cf030c7c800c098fac0fde54294835fc3c8f1))

### Ci

* ci: run ci ([`5ec12e0`](https://github.com/MartinBernstorff/iterpy/commit/5ec12e09400f0ff9bc4f101adf845b572594c765))

### Fix

* fix: Iter[iter].flatten() should return Iter (#94)

fix: Iter[iter].flatten() should return Iter

update _iter.py and test_iter.py ([`c8790a7`](https://github.com/MartinBernstorff/iterpy/commit/c8790a762b0d2d1e9f03d1da0e6e1a74db306e94))

* fix: Iter[iter].flatten() should return Iter ([`f371f6a`](https://github.com/MartinBernstorff/iterpy/commit/f371f6a0672280ab1e11687514097d24b56b49d5))

### Refactor

* refactor: tidy up ([`afc69d9`](https://github.com/MartinBernstorff/iterpy/commit/afc69d93c2fed8709ce5978bd17a840e0752cdc6))

### Unknown

* update _iter.py and test_iter.py ([`e7f776c`](https://github.com/MartinBernstorff/iterpy/commit/e7f776c36e05d86fa4d28072dcd1ca949ca470d6))

* Fix(#83): type for Iter[Iter].flatten() (#93) ([`c2ea2d3`](https://github.com/MartinBernstorff/iterpy/commit/c2ea2d3cbc85d9452b669c389f7749804aad7798))

* dev(#89): simplify dev container (#92) ([`ce7591d`](https://github.com/MartinBernstorff/iterpy/commit/ce7591d970806af01017720e2eab319ab5d8f2e0))

* update _generate_pyi.py, _iter.py, _iter.pyi and test_iter.py ([`d0b5a0a`](https://github.com/MartinBernstorff/iterpy/commit/d0b5a0aa147453fd565dc5ba2a163f0687628b70))

* Fix(#83): type for Iter[Iter].flatten()

Fixes #83 ([`fb81fd8`](https://github.com/MartinBernstorff/iterpy/commit/fb81fd801f39d737c0dafc08915e2507c011428c))

* update _iter.py and _iter.pyi ([`9e45635`](https://github.com/MartinBernstorff/iterpy/commit/9e45635b2e681410580cd565f408656816e3bb7f))

* dev(#89): simplify dev container

Fixes #89 ([`b6c0f19`](https://github.com/MartinBernstorff/iterpy/commit/b6c0f19f7fdb84a2b65d8a58f2e4e89dd8f3ce32))

* dev(#89): simplify dev container

Fixes #89 ([`024599c`](https://github.com/MartinBernstorff/iterpy/commit/024599cdefd77c76f556fc420717d7ff61bdac31))

* Delete functionalpy.egg-info directory ([`adbc4a4`](https://github.com/MartinBernstorff/iterpy/commit/adbc4a4591229832854c9ece35c41e17036d7b74))

* deps:(deps-dev): bump ruff from 0.1.13 to 0.1.14 (#88) ([`3d694cc`](https://github.com/MartinBernstorff/iterpy/commit/3d694cc8680f655fe4ff6ba0d4ce0e2620f10e35))

* deps:(deps-dev): bump ruff from 0.1.13 to 0.1.14

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.13 to 0.1.14.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.13...v0.1.14)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`9fcdb4f`](https://github.com/MartinBernstorff/iterpy/commit/9fcdb4f779799a70baefc3e2bf73ebcb77bb9618))

* deps:(deps-dev): bump diff-cover from 8.0.2 to 8.0.3 (#87) ([`c7ea3db`](https://github.com/MartinBernstorff/iterpy/commit/c7ea3dbeb83c43f7124ef087e96595b88abdbfc0))

* deps:(deps-dev): bump pyright from 1.1.346 to 1.1.348 (#86) ([`06084f9`](https://github.com/MartinBernstorff/iterpy/commit/06084f9a2a8caf94c06267e4b337e4db73cc4552))

* deps:(deps-dev): bump diff-cover from 8.0.2 to 8.0.3

Bumps [diff-cover](https://github.com/Bachmann1234/diff-cover) from 8.0.2 to 8.0.3.
- [Release notes](https://github.com/Bachmann1234/diff-cover/releases)
- [Changelog](https://github.com/Bachmann1234/diff_cover/blob/main/CHANGELOG)
- [Commits](https://github.com/Bachmann1234/diff-cover/compare/v8.0.2...v8.0.3)

---
updated-dependencies:
- dependency-name: diff-cover
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`bbf82a4`](https://github.com/MartinBernstorff/iterpy/commit/bbf82a422575279bb8f9de1d7d31ee48dc16d688))

* deps:(deps-dev): bump pyright from 1.1.346 to 1.1.348

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.346 to 1.1.348.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.346...v1.1.348)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`28c1c3a`](https://github.com/MartinBernstorff/iterpy/commit/28c1c3ab49e13765c2a091453cf0aa82e40563b2))

* deps:(deps-dev): bump ruff from 0.1.11 to 0.1.13 (#85) ([`36fe2c3`](https://github.com/MartinBernstorff/iterpy/commit/36fe2c3b97d9aec2832a4e984bc5ab49338289cc))

* deps:(deps-dev): bump pyright from 1.1.344 to 1.1.346 (#84) ([`886d7a2`](https://github.com/MartinBernstorff/iterpy/commit/886d7a224430bb41f19bc23c676ddaac10e00782))

* deps:(deps-dev): bump ruff from 0.1.11 to 0.1.13

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.11 to 0.1.13.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.11...v0.1.13)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`186f128`](https://github.com/MartinBernstorff/iterpy/commit/186f128856126ad4fe5d3d90ebcf33e3553e39bf))

* deps:(deps-dev): bump pyright from 1.1.344 to 1.1.346

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.344 to 1.1.346.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.344...v1.1.346)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`91610a8`](https://github.com/MartinBernstorff/iterpy/commit/91610a87d248404b1f0a514f580ff44890d3c85a))

* deps:(deps-dev): bump ruff from 0.1.9 to 0.1.11 (#82) ([`10a05a2`](https://github.com/MartinBernstorff/iterpy/commit/10a05a2d3fd0b50d8af609c1807920d6dfe5e4c5))

* deps:(deps-dev): bump ruff from 0.1.9 to 0.1.11

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.9 to 0.1.11.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.9...v0.1.11)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`4c22487`](https://github.com/MartinBernstorff/iterpy/commit/4c2248782f296a69a9b0f14bae321b02c648a4d5))


## v0.22.0 (2024-01-04)

### Documentation

* docs: misc. readme ([`87298aa`](https://github.com/MartinBernstorff/iterpy/commit/87298aae7c38f46559e72727beecd6218cbe2411))

### Feature

* feat: remove statefulness (#81) ([`130c02f`](https://github.com/MartinBernstorff/iterpy/commit/130c02f3cea9cccc9b7662b16910f222ad055529))

* feat: ensure `Iter`&#39;s lack of statefulness

Fixes #71. ([`3dfc289`](https://github.com/MartinBernstorff/iterpy/commit/3dfc28989a8c902f4d8bc6fcf1235dd5958f464e))

* feat: ensure `Iter` is an iterator.

Fixes #71 ([`124d807`](https://github.com/MartinBernstorff/iterpy/commit/124d8070583d339194fa0a726568f91a900651dc))

### Unknown

* Merge remote-tracking branch &#39;origin/main&#39; into 71-feat-ensure-`Iter`-is-an-iterator ([`b7cec4a`](https://github.com/MartinBernstorff/iterpy/commit/b7cec4abecc5a59f7fc969fc5f88e1e4d7347511))

* Update README.md ([`d65202c`](https://github.com/MartinBernstorff/iterpy/commit/d65202cc8172c77f508d6b3ff6e68df3ea5d234b))


## v0.21.0 (2024-01-04)

### Feature

* feat: rename to iterpy (#80) ([`e6584ef`](https://github.com/MartinBernstorff/iterpy/commit/e6584ef8265da8c19901877f815fa1417a7c636a))

### Fix

* fix: rename ([`5d4f08e`](https://github.com/MartinBernstorff/iterpy/commit/5d4f08e7ccb003c52176498d9fdb823f7281e9dd))

* fix: typo ([`d054c40`](https://github.com/MartinBernstorff/iterpy/commit/d054c40ca0aa74642a7127f5934bda6e3ebcca17))

### Unknown

* misc. ([`509915f`](https://github.com/MartinBernstorff/iterpy/commit/509915f2e690701ec477750c6459e5280db5665f))

* Merge remote-tracking branch &#39;origin/main&#39; into mbern_rename_to_iterpy ([`de398ab`](https://github.com/MartinBernstorff/iterpy/commit/de398ab4f86a7e53b396f62e5b6c8785989bf557))

* major: rename to iterpy to align with pypi ([`0279a65`](https://github.com/MartinBernstorff/iterpy/commit/0279a653e691eed5422042bc7153afbe7a8e40b0))


## v0.20.0 (2024-01-04)

### Ci

* ci: add workflow_dispatch ([`9f5f45f`](https://github.com/MartinBernstorff/iterpy/commit/9f5f45f3b471c46e478310526cf68b0221861ba8))

### Feature

* feat: update minor version ([`263b4ca`](https://github.com/MartinBernstorff/iterpy/commit/263b4ca0f420560a8cab03e1fb86698387125b4f))

### Unknown

*  deps remove polars from default dependencies (#79) ([`17f74f6`](https://github.com/MartinBernstorff/iterpy/commit/17f74f6f17cc9aea409e29a1bc5e178a57099230))

* deps: separate benchmark deps

Fixes deps: remove polars from default dependencies #77. ([`6450bf1`](https://github.com/MartinBernstorff/iterpy/commit/6450bf10ea6a665b547a5d271742938ff5a2b6fd))


## v0.19.0 (2024-01-01)

### Feature

* feat: update version ([`d505159`](https://github.com/MartinBernstorff/iterpy/commit/d505159c0b0be412ef9767f95cd7cfcfb0f45e81))

### Refactor

* refactor: rename to iter

Fixes #56. ([`3172904`](https://github.com/MartinBernstorff/iterpy/commit/3172904a838329a82e9ffbd99bbd926c5b9c4ded))

### Unknown

* mbern_refactor_rename_to_iter (#75) ([`3570a1e`](https://github.com/MartinBernstorff/iterpy/commit/3570a1ed3c622f71362d599592c371d242342b51))

* misc. ([`57d1cc3`](https://github.com/MartinBernstorff/iterpy/commit/57d1cc350e879797b4d76ba61d31e4b48edcfcdc))

* Merge remote-tracking branch &#39;origin/main&#39; into mbern_refactor_rename_to_iter ([`2b25ef2`](https://github.com/MartinBernstorff/iterpy/commit/2b25ef23de8da6b9f3e2a1fee33102c7664e3435))


## v0.18.0 (2024-01-01)

### Feature

* feat: autogenerate and extend overloads (#74) ([`33197c3`](https://github.com/MartinBernstorff/iterpy/commit/33197c33e50a0bef0c751c0a5192ae86cf3e5a06))

* feat: support flattening all sequence types and Seq[_S] | _S

Fixes #68. ([`81dc62a`](https://github.com/MartinBernstorff/iterpy/commit/81dc62a56b27ac0787e4597452a6e13a728cc5eb))

### Unknown

* tests: misc ([`fb5efda`](https://github.com/MartinBernstorff/iterpy/commit/fb5efda0c7cab0747391221276a201a63c8c166c))

* misc. ([`e9719ed`](https://github.com/MartinBernstorff/iterpy/commit/e9719edd212751253f3c9441a8f24923f93ec3f3))

* misc. ([`5ab005a`](https://github.com/MartinBernstorff/iterpy/commit/5ab005a506164ed924574efac98b9846e9d84cd7))


## v0.17.0 (2024-01-01)

### Feature

* feat: add graphite (#73) ([`79fa18e`](https://github.com/MartinBernstorff/iterpy/commit/79fa18e44b3b3383e6dd3feca8e248402f128dd4))

* feat: add graphite ([`ae1f0fa`](https://github.com/MartinBernstorff/iterpy/commit/ae1f0fa0b375f095d1059bbbd303ccbf8e279451))


## v0.16.0 (2024-01-01)

### Documentation

* docs: expand prior art with fluid

Fixes #62 ([`cf0d791`](https://github.com/MartinBernstorff/iterpy/commit/cf0d791b996159f161fa423aca657d2cc92ba7d6))

### Feature

* feat: implement __getitem__ (#72) ([`1dd6588`](https://github.com/MartinBernstorff/iterpy/commit/1dd6588bccb05e1b7bc85a29135a899b44626f0c))

* feat: implement __getitem__

Fixes #65 ([`f27ee52`](https://github.com/MartinBernstorff/iterpy/commit/f27ee52ff21091f766403caeb6f2966e8770b35c))

### Fix

* fix: .flatten should not flatten strings

Fixes #60 ([`f0982fe`](https://github.com/MartinBernstorff/iterpy/commit/f0982feb79de4fa0022d62aa9eb2c7ff5229e9e1))

* fix: groupby should yield tuples of (key, Seq[_T])

Fixes #64 ([`e2f225d`](https://github.com/MartinBernstorff/iterpy/commit/e2f225d73d101afc767edb4f0f9f24e8b502236d))

### Unknown

* Merge branch &#39;main&#39; into 65-feat-implement-__getitem__ ([`f120b34`](https://github.com/MartinBernstorff/iterpy/commit/f120b34fd20b7d8e2502c67b7cd69344c8ac8cfa))

* misc. ([`3578648`](https://github.com/MartinBernstorff/iterpy/commit/35786487d77b0895e33e75f2468143cd67cc09be))

* misc. ([`07e843b`](https://github.com/MartinBernstorff/iterpy/commit/07e843b4e638bd66acf548aa864f52249e705ede))

* deps:(deps-dev): bump pytest from 7.4.3 to 7.4.4

Bumps [pytest](https://github.com/pytest-dev/pytest) from 7.4.3 to 7.4.4.
- [Release notes](https://github.com/pytest-dev/pytest/releases)
- [Changelog](https://github.com/pytest-dev/pytest/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest/compare/7.4.3...7.4.4)

---
updated-dependencies:
- dependency-name: pytest
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`a845e7f`](https://github.com/MartinBernstorff/iterpy/commit/a845e7f7bd9ebc1429bdc6333fa798d2d551a5fe))

* deps:(deps-dev): bump pyright from 1.1.342 to 1.1.344

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.342 to 1.1.344.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.342...v1.1.344)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`06794b5`](https://github.com/MartinBernstorff/iterpy/commit/06794b53bbbb02ed0a3a9d78ed91e05b522330b2))

* misc. ([`01b54cc`](https://github.com/MartinBernstorff/iterpy/commit/01b54cc171de4878495bde0b3a6adef6a51cef55))

* misc. ([`fcf3ba4`](https://github.com/MartinBernstorff/iterpy/commit/fcf3ba4166c350a8b0c8ced2da0978b59290f131))

* Update README.md ([`a78874c`](https://github.com/MartinBernstorff/iterpy/commit/a78874c4266ba8c7e25a5000a140b018050dc4e5))

* misc. ([`c05f609`](https://github.com/MartinBernstorff/iterpy/commit/c05f6094baaf564773a48ebe19a8bcd38f987880))

* deps:(deps-dev): bump pytest from 7.4.3 to 7.4.4 (#70) ([`bfa28de`](https://github.com/MartinBernstorff/iterpy/commit/bfa28de18e4b9f24b6503b2c183ab091765f80ad))

* deps:(deps-dev): bump pytest from 7.4.3 to 7.4.4

Bumps [pytest](https://github.com/pytest-dev/pytest) from 7.4.3 to 7.4.4.
- [Release notes](https://github.com/pytest-dev/pytest/releases)
- [Changelog](https://github.com/pytest-dev/pytest/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pytest-dev/pytest/compare/7.4.3...7.4.4)

---
updated-dependencies:
- dependency-name: pytest
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`4fec726`](https://github.com/MartinBernstorff/iterpy/commit/4fec726a3a9239d2058a266475374c10dc70e9f2))

* deps:(deps-dev): bump pyright from 1.1.342 to 1.1.344 (#69) ([`f98a484`](https://github.com/MartinBernstorff/iterpy/commit/f98a484430384c0220628edbfd9825a015be3dd5))

* deps:(deps-dev): bump pyright from 1.1.342 to 1.1.344

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.342 to 1.1.344.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.342...v1.1.344)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`b5471dc`](https://github.com/MartinBernstorff/iterpy/commit/b5471dc487495311a0b33e0dbab5ddbaf5944293))


## v0.15.2 (2024-01-01)

### Documentation

* docs: expand prior art with fluid

Fixes #62 ([`c823d78`](https://github.com/MartinBernstorff/iterpy/commit/c823d781be85d09396c2125f50efce64844cb0d8))

### Fix

* fix: groupby should yield tuples of (key, Seq[_T])

Fixes #64 ([`b9a60ea`](https://github.com/MartinBernstorff/iterpy/commit/b9a60ea55f7a2645fb4d4ba7156b4b66a0c8c8da))

### Unknown

*  fix groupby should yield tuples of key Seq_T (#67) ([`ad8293b`](https://github.com/MartinBernstorff/iterpy/commit/ad8293b5ef6680c8271cb1cbcb8f0af6c8124806))

* misc. ([`2b4dcd1`](https://github.com/MartinBernstorff/iterpy/commit/2b4dcd18c834fb5b38627dff7358ef49092ba161))

* Merge remote-tracking branch &#39;origin/main&#39; into 64-fix-groupby-should-yield-tuples-of-key-Seq_T ([`05d7d54`](https://github.com/MartinBernstorff/iterpy/commit/05d7d5458908575d3cfecde1b15634b591e2b735))

*  docs expand prior art with fluid (#66) ([`465814b`](https://github.com/MartinBernstorff/iterpy/commit/465814b862edcb6fa7cd1bc86cd3ed63fdb9b97e))

* misc. ([`e842586`](https://github.com/MartinBernstorff/iterpy/commit/e8425867347ee9564076808bbbf02ad564b6a6ae))

* Merge remote-tracking branch &#39;origin/main&#39; into 62-docs-expand-prior-art-with-fluid ([`b7abd1a`](https://github.com/MartinBernstorff/iterpy/commit/b7abd1ae778094ba69496382a1a4777188d33208))

* misc. ([`4d509e1`](https://github.com/MartinBernstorff/iterpy/commit/4d509e18770f65d048e40585ba01194c80989d37))


## v0.15.1 (2024-01-01)

### Fix

* fix: .flatten should not flatten strings

Fixes #60 ([`7723d07`](https://github.com/MartinBernstorff/iterpy/commit/7723d0779713a761a8d5e47f674dfa28f693adc6))

### Unknown

*  fix flatten should not flatten strings (#63) ([`f10d6ca`](https://github.com/MartinBernstorff/iterpy/commit/f10d6ca65e5c798135b8f718828983b46e273793))

* Merge remote-tracking branch &#39;origin/main&#39; into 60-fix-flatten-should-not-flatten-strings ([`866cd47`](https://github.com/MartinBernstorff/iterpy/commit/866cd47c492d8b35759b399efe79a9c81359cc3b))

* Update README.md ([`ca1ae38`](https://github.com/MartinBernstorff/iterpy/commit/ca1ae3852099f40bfeb8b2e4d80f9e21f4047458))


## v0.15.0 (2023-12-31)

### Feature

* feat: flatten should remove empty sequences ([`06c1d75`](https://github.com/MartinBernstorff/iterpy/commit/06c1d75a419d2b9f13d5c26baf211d853bd2454d))

### Fix

* fix: flatten should preserve primitives ([`2284c93`](https://github.com/MartinBernstorff/iterpy/commit/2284c935d2a00494bffe5848d5114eeeac800035))

### Unknown

* mbern_typeguard_flatten_none (#59) ([`95f7ab0`](https://github.com/MartinBernstorff/iterpy/commit/95f7ab089552537e21d3e6a1e06d4bfb0888dc6b))

* Merge remote-tracking branch &#39;origin/main&#39; into mbern_typeguard_flatten_none ([`af5b937`](https://github.com/MartinBernstorff/iterpy/commit/af5b937ec7beb32a56ac62da340404196a707e83))

* mbern_feat_flatten_sequence_type (#55) ([`7902c4c`](https://github.com/MartinBernstorff/iterpy/commit/7902c4cf6e8b78a8c60f256d093fcdd5659f7529))

* misc. ([`a021397`](https://github.com/MartinBernstorff/iterpy/commit/a021397956c6187ac972794f77e188df7b6f1e20))

* misc. ([`885c73e`](https://github.com/MartinBernstorff/iterpy/commit/885c73ec2edd61b3d0c081e298a425bd9bfc6c1e))

* deps:(deps-dev): bump ruff from 0.1.8 to 0.1.9 (#54) ([`be8718c`](https://github.com/MartinBernstorff/iterpy/commit/be8718c829494c6facdba9398337ed00ac0fde96))

* deps:(deps-dev): bump pyright from 1.1.341 to 1.1.342 (#53) ([`1e36011`](https://github.com/MartinBernstorff/iterpy/commit/1e3601161344548099c57bcc23552f596e0d0f49))

* deps:(deps-dev): bump ruff from 0.1.8 to 0.1.9

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.8...v0.1.9)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`ab7605e`](https://github.com/MartinBernstorff/iterpy/commit/ab7605e54426171f6f4e82f2cb953c9b030097f0))

* deps:(deps-dev): bump pyright from 1.1.341 to 1.1.342

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.341 to 1.1.342.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.341...v1.1.342)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`80671da`](https://github.com/MartinBernstorff/iterpy/commit/80671dabcc2a0137c98a9ccadb9ce80050e6ce27))

* deps:(deps-dev): bump diff-cover from 8.0.1 to 8.0.2 (#51) ([`2eaef79`](https://github.com/MartinBernstorff/iterpy/commit/2eaef79bfb4e5e2f9e95d49485ed87429067afe4))

* deps:(deps-dev): bump diff-cover from 8.0.1 to 8.0.2

Bumps [diff-cover](https://github.com/Bachmann1234/diff-cover) from 8.0.1 to 8.0.2.
- [Release notes](https://github.com/Bachmann1234/diff-cover/releases)
- [Changelog](https://github.com/Bachmann1234/diff_cover/blob/main/CHANGELOG)
- [Commits](https://github.com/Bachmann1234/diff-cover/compare/v8.0.1...v8.0.2)

---
updated-dependencies:
- dependency-name: diff-cover
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`6034836`](https://github.com/MartinBernstorff/iterpy/commit/60348363f5b7a3107269ab1a8fb55e39dea115d0))

* deps:(deps-dev): bump ruff from 0.1.7 to 0.1.8 (#52) ([`1f84929`](https://github.com/MartinBernstorff/iterpy/commit/1f84929ab1ff27fb98a7fabb138774b306e1e51f))

* deps:(deps-dev): bump pyright from 1.1.339 to 1.1.341 (#50) ([`687caf2`](https://github.com/MartinBernstorff/iterpy/commit/687caf2637368cdb2ca640ac511355df75f85aac))

* deps:(deps-dev): bump ruff from 0.1.7 to 0.1.8

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.7 to 0.1.8.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.7...v0.1.8)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`f428c86`](https://github.com/MartinBernstorff/iterpy/commit/f428c8668fd85d8ee2d8ecdf722bc4f57b027f73))

* deps:(deps-dev): bump pyright from 1.1.339 to 1.1.341

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.339 to 1.1.341.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.339...v1.1.341)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`469ed8b`](https://github.com/MartinBernstorff/iterpy/commit/469ed8b73a1fdffd3a64199157119852d72d0b98))

* deps:(deps-dev): bump ruff from 0.1.6 to 0.1.7 (#49) ([`684f312`](https://github.com/MartinBernstorff/iterpy/commit/684f312876a7ea0e1e6f4b00910e016c4e05c48e))

* deps:(deps-dev): bump pyright from 1.1.338 to 1.1.339 (#48) ([`d8778d9`](https://github.com/MartinBernstorff/iterpy/commit/d8778d994486e5610701fd1a94107c0226bc79cd))

* deps:(deps-dev): bump ruff from 0.1.6 to 0.1.7

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.6 to 0.1.7.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.6...v0.1.7)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`ca7bc94`](https://github.com/MartinBernstorff/iterpy/commit/ca7bc9498daefb8196f2d0973ccce924918dec17))

* deps:(deps-dev): bump pyright from 1.1.338 to 1.1.339

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.338 to 1.1.339.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.338...v1.1.339)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`c21d84f`](https://github.com/MartinBernstorff/iterpy/commit/c21d84f786df17d2b7a8adb655dc47a44233fc48))

* deps:(deps-dev): bump pyright from 1.1.337 to 1.1.338 (#47) ([`1fc5c79`](https://github.com/MartinBernstorff/iterpy/commit/1fc5c79084508df265296cd78e380306921b6a5a))

* deps:(deps-dev): bump pyright from 1.1.337 to 1.1.338

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.337 to 1.1.338.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.337...v1.1.338)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`b61be2b`](https://github.com/MartinBernstorff/iterpy/commit/b61be2bbf6c3f5fccf5d391f0e5c676d0db88fea))

* Update README.md ([`382895d`](https://github.com/MartinBernstorff/iterpy/commit/382895d1950826e1f73f41e849df299e86a557c1))

* Update README.md ([`68de6dd`](https://github.com/MartinBernstorff/iterpy/commit/68de6ddd9b09e605757e037b9a2d31599edaec9b))

* Update README.md ([`ead1d1b`](https://github.com/MartinBernstorff/iterpy/commit/ead1d1b75e75ee22bfbedcb8379446b0fe33cce1))


## v0.14.0 (2023-11-28)

### Ci

* ci: ensure good coverage (codecov)

Fixes #43 ([`45e7734`](https://github.com/MartinBernstorff/iterpy/commit/45e7734d6afa28cc217e48f6ec4ddad3fa2ea34e))

* ci: ensure .pyi files are aligned with implementation

Fixes ci: ensure .pyi files are aligned with implementation #38

(This happens automatically when types are hard-coded in the tests) ([`aa25b4d`](https://github.com/MartinBernstorff/iterpy/commit/aa25b4d44c5d6929e4ca2c1d5c365d25831da3a9))

### Feature

* feat: add pmap (#46) ([`72a337e`](https://github.com/MartinBernstorff/iterpy/commit/72a337eadf504df7a69c576ea9e857f17e75bb37))

* feat: add pmap ([`2bd63cf`](https://github.com/MartinBernstorff/iterpy/commit/2bd63cfc79b2234cc9756f13653633d140ba0085))

### Unknown

* misc. ([`6d365cd`](https://github.com/MartinBernstorff/iterpy/commit/6d365cdd1e2627cb21b7e2edc45ee240f25cd5a1))

* misc. ([`b7d560c`](https://github.com/MartinBernstorff/iterpy/commit/b7d560ceeb515c62ab0f880c7de0ca9df6ccb1db))

* Update README.md ([`0243b33`](https://github.com/MartinBernstorff/iterpy/commit/0243b3309a2043c94596850fd8821ae14483b8e5))

* Update README.md ([`9123ccd`](https://github.com/MartinBernstorff/iterpy/commit/9123ccd2a8c7928770779d37ecbeb8e642b7565c))

* Update README.md ([`3827e46`](https://github.com/MartinBernstorff/iterpy/commit/3827e466256f17018abf4f8e597112fb96f32b2a))

*  ci ensure good coverage codecov (#44) ([`268720c`](https://github.com/MartinBernstorff/iterpy/commit/268720c78c95a381185950525ee99b536f5ec659))

* Merge remote-tracking branch &#39;origin/main&#39; into 43-ci-ensure-good-coverage-codecov ([`e6660e6`](https://github.com/MartinBernstorff/iterpy/commit/e6660e6771cecc5aa15ef7e297ef72b1db2621a1))

*  ci ensure pyi files are aligned with implementation (#42) ([`a4edd47`](https://github.com/MartinBernstorff/iterpy/commit/a4edd47857530f1109efc8edc5797c82611817bf))

* misc. ([`1ef8f98`](https://github.com/MartinBernstorff/iterpy/commit/1ef8f985c98a9ede14793bc645be25030b755687))


## v0.13.0 (2023-11-28)

### Ci

* ci: validate in ci ([`8d91050`](https://github.com/MartinBernstorff/iterpy/commit/8d910502c6901e0c9e255fa603de06cbc0d17249))

* ci: update cruft ([`d9c98b7`](https://github.com/MartinBernstorff/iterpy/commit/d9c98b7417a0266291a5d6016be6eb898bbeef3e))

### Feature

* feat: turn groupby into mapping (#39) ([`c4fb33c`](https://github.com/MartinBernstorff/iterpy/commit/c4fb33c3057cbb0aadc0a44cc93d3d47207a7190))

### Unknown

*  tests should assert types (#41) ([`176cf74`](https://github.com/MartinBernstorff/iterpy/commit/176cf74cc2ce05cccaaec660736111124b26976c))

* tests: hardcode types to ensure alignment

Fixes #37 ([`97075ea`](https://github.com/MartinBernstorff/iterpy/commit/97075ea2b9e0157d57f7a7d22b31f2c6c6f79f2a))

* Update README.md ([`b3f9de1`](https://github.com/MartinBernstorff/iterpy/commit/b3f9de1a562cd4e1d89d6726fb1a342bff680894))

* misc. ([`6400d7d`](https://github.com/MartinBernstorff/iterpy/commit/6400d7d5e3a1a0da5e35eff246b8911d158c4d7e))

* misc. ([`2d03d36`](https://github.com/MartinBernstorff/iterpy/commit/2d03d365e87846c450d81c7da1de98f6275098b8))

* misc: update example ([`4b0c138`](https://github.com/MartinBernstorff/iterpy/commit/4b0c13875a4552bee3d1193cca9ed857b2855701))

* misc. ([`6ab44ca`](https://github.com/MartinBernstorff/iterpy/commit/6ab44caa8bb8dafbad29b880bcee2f2c8d404984))

* misc. ([`1d1a51a`](https://github.com/MartinBernstorff/iterpy/commit/1d1a51a71a3fee7a9cfcf2a3533e19893ab98a08))

* Merge remote-tracking branch &#39;origin/main&#39; into 35-Properly-specify-groupby ([`347f3bb`](https://github.com/MartinBernstorff/iterpy/commit/347f3bb4e6c9bbc068701e40fe209bb7939958df))

* Properly specify groupby

Fixes #35 ([`9ef79c3`](https://github.com/MartinBernstorff/iterpy/commit/9ef79c3155f2e4d06322932733e89352cd464804))

* deps:(deps-dev): bump pyright from 1.1.336 to 1.1.337 (#36) ([`1824012`](https://github.com/MartinBernstorff/iterpy/commit/1824012e7724abdb99f5f90f2692469d54d8352b))

* deps:(deps-dev): bump pyright from 1.1.336 to 1.1.337

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.336 to 1.1.337.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.336...v1.1.337)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`93e898b`](https://github.com/MartinBernstorff/iterpy/commit/93e898bf4110b5ec4ed315707753d2844ae76f31))

* Merge pull request #33 from MartinBernstorff/mbern_update_cruft

ci: update cruft ([`c6211ac`](https://github.com/MartinBernstorff/iterpy/commit/c6211ac72b894d90b6b4e7d34381d387418e7eb9))

* misc. ([`5e8bef2`](https://github.com/MartinBernstorff/iterpy/commit/5e8bef2b1c02ba66ea844998861de38829317520))

* misc. ([`0f42748`](https://github.com/MartinBernstorff/iterpy/commit/0f42748c91ae1ae0d303f065bcc24841ba5d675d))

* Merge pull request #32 from MartinBernstorff/dependabot/pip/ruff-0.1.6

deps:(deps-dev): bump ruff from 0.1.5 to 0.1.6 ([`83704ae`](https://github.com/MartinBernstorff/iterpy/commit/83704ae6e57cfb1fd6c91ca519aab8c0b39eae85))

* deps:(deps-dev): bump ruff from 0.1.5 to 0.1.6

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.5...v0.1.6)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`dcefbb0`](https://github.com/MartinBernstorff/iterpy/commit/dcefbb0166ead2af63c5424a37f2f083bf9c1ab9))

* Merge pull request #31 from MartinBernstorff/dependabot/pip/pyright-1.1.336

deps:(deps-dev): bump pyright from 1.1.335 to 1.1.336 ([`d547e9d`](https://github.com/MartinBernstorff/iterpy/commit/d547e9d344b69c0b7601c9017f51d2e65add4c5e))

* deps:(deps-dev): bump pyright from 1.1.335 to 1.1.336

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.335 to 1.1.336.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.335...v1.1.336)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`3c9dfbb`](https://github.com/MartinBernstorff/iterpy/commit/3c9dfbb2c2f83a22800f1d3033fc667d6981334d))


## v0.12.0 (2023-11-17)

### Feature

* feat: include typing ([`1b78e47`](https://github.com/MartinBernstorff/iterpy/commit/1b78e470121599d74174f61ba646d4dce36a8582))

### Unknown

* Merge pull request #29 from MartinBernstorff/mbern_ensure_type_stubs_added

feat: include typing in pypi distribution ([`cdd1463`](https://github.com/MartinBernstorff/iterpy/commit/cdd1463c48e99f32880aaea87c0d40555fda3d2b))

* misc. ([`8635152`](https://github.com/MartinBernstorff/iterpy/commit/8635152d5934907035a96dce996ebcac1a7c9dc5))


## v0.11.0 (2023-11-16)

### Feature

* feat: add pyi ([`02ee06a`](https://github.com/MartinBernstorff/iterpy/commit/02ee06a7fdd966e8eff952fb93bb5f0814a24fea))

### Unknown

* Merge pull request #28 from MartinBernstorff/mbern_add_pyi_version_bump

feat: add pyi ([`72decb9`](https://github.com/MartinBernstorff/iterpy/commit/72decb948847a7e1f36bd07aa763ce78ee2496b0))

* Merge pull request #27 from MartinBernstorff/dependabot/pip/pyright-1.1.335

deps:(deps-dev): bump pyright from 1.1.334 to 1.1.335 ([`80c7aec`](https://github.com/MartinBernstorff/iterpy/commit/80c7aecdaa69781823160e4b11f5f5fda5ea0004))

* deps:(deps-dev): bump pyright from 1.1.334 to 1.1.335

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.334 to 1.1.335.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.334...v1.1.335)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`3482335`](https://github.com/MartinBernstorff/iterpy/commit/3482335d382673ec323d05b141d3983ae7097a5d))

* Merge pull request #26 from MartinBernstorff/dependabot/pip/ruff-0.1.5

deps:(deps-dev): bump ruff from 0.1.4 to 0.1.5 ([`0fc3d6d`](https://github.com/MartinBernstorff/iterpy/commit/0fc3d6d53c73eb7794deaab63a37bab915e971bf))

* deps:(deps-dev): bump ruff from 0.1.4 to 0.1.5

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.4...v0.1.5)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`6ba01da`](https://github.com/MartinBernstorff/iterpy/commit/6ba01dab9e86ae1bca6eae8f8b849e0d434783d7))

* Merge pull request #25 from MartinBernstorff/dependabot/pip/pyright-1.1.334

deps:(deps-dev): bump pyright from 1.1.333 to 1.1.334 ([`1215a6e`](https://github.com/MartinBernstorff/iterpy/commit/1215a6e54f4162e2ca08ede3f78172c353fd3e46))

* deps:(deps-dev): bump pyright from 1.1.333 to 1.1.334

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.333 to 1.1.334.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.333...v1.1.334)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`f00e7d9`](https://github.com/MartinBernstorff/iterpy/commit/f00e7d9b96c92abb9709bf01a0a81f4a1b489674))

* Merge pull request #24 from MartinBernstorff/dependabot/pip/ruff-0.1.4

deps:(deps-dev): bump ruff from 0.1.3 to 0.1.4 ([`dbd09e7`](https://github.com/MartinBernstorff/iterpy/commit/dbd09e7b537d2adf0f852411989e8b3a000d8cc3))

* deps:(deps-dev): bump ruff from 0.1.3 to 0.1.4

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.3 to 0.1.4.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.3...v0.1.4)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`e52627c`](https://github.com/MartinBernstorff/iterpy/commit/e52627c282cda0a87de09d1c7020a6971a5c7a34))


## v0.10.0 (2023-10-30)

### Feature

* feat: add pyi for flatten method ([`3e9af4e`](https://github.com/MartinBernstorff/iterpy/commit/3e9af4e7b23b7b42c5eed1ef9716802b0a1275b7))

### Unknown

* Merge pull request #23 from MartinBernstorff/mb/feat_add_pyi_for_flatten

feat: add pyi for flatten method ([`7e70edb`](https://github.com/MartinBernstorff/iterpy/commit/7e70edb0a7381e7fbeef65aced65625ea623108f))

* lint: ignore pyi errors ([`78bc32c`](https://github.com/MartinBernstorff/iterpy/commit/78bc32c8663785476714ff935d418f13cb4b58e4))

* Merge pull request #22 from MartinBernstorff/dependabot/pip/ruff-0.1.3

deps:(deps-dev): bump ruff from 0.1.2 to 0.1.3 ([`0093340`](https://github.com/MartinBernstorff/iterpy/commit/0093340c426c57b9865f8694a004f58038c11fb4))

* deps:(deps-dev): bump ruff from 0.1.2 to 0.1.3

Bumps [ruff](https://github.com/astral-sh/ruff) from 0.1.2 to 0.1.3.
- [Release notes](https://github.com/astral-sh/ruff/releases)
- [Changelog](https://github.com/astral-sh/ruff/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/ruff/compare/v0.1.2...v0.1.3)

---
updated-dependencies:
- dependency-name: ruff
  dependency-type: direct:development
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`4ed49a3`](https://github.com/MartinBernstorff/iterpy/commit/4ed49a31f133eaf2ab344fe270406e477abb90e3))


## v0.9.0 (2023-10-30)

### Ci

* ci: formatting updates ([`6281469`](https://github.com/MartinBernstorff/iterpy/commit/62814699a24ee03d3fe42e6deb47494b280ff266))

### Feature

* feat: bump version ([`8362ffd`](https://github.com/MartinBernstorff/iterpy/commit/8362ffd6a09a7b921997144f4a75168fb6aa1908))

* feat: bump version ([`1ecb3dc`](https://github.com/MartinBernstorff/iterpy/commit/1ecb3dc49ee41ae238bcb9a9d13b4b60b4389376))

### Unknown

* Merge pull request #21 from MartinBernstorff/mb/update_cruft

ci: update cruft ([`3041d77`](https://github.com/MartinBernstorff/iterpy/commit/3041d773b299dd76ce60238d44334b470ba6eedf))

* Merge branch &#39;main&#39; into mb/update_cruft ([`629af45`](https://github.com/MartinBernstorff/iterpy/commit/629af4510c78ec18057100ffbdbe98c6117e0461))

* dev: add cruft as dependency ([`5c05d02`](https://github.com/MartinBernstorff/iterpy/commit/5c05d02f5e7b0549ec43083ef7e363d6881e295d))

* tests: update import ([`ca75a7d`](https://github.com/MartinBernstorff/iterpy/commit/ca75a7d211d990e88167e9c78fa62911e7386706))

* dev: make sequence module private ([`7aa4abd`](https://github.com/MartinBernstorff/iterpy/commit/7aa4abda3d8acf719f09a8f98bba5c1729593d84))


## v0.8.0 (2023-10-30)

### Ci

* ci: update cruft ([`888906b`](https://github.com/MartinBernstorff/iterpy/commit/888906b1c33e2afa406d738ca0b83b33be8181d2))

### Feature

* feat: bump version ([`7c026b7`](https://github.com/MartinBernstorff/iterpy/commit/7c026b7fdc7a5b743f2744d80dd7ad1736a3b311))

### Unknown

* Merge pull request #20 from MartinBernstorff/make_sequence_module_private

dev: make sequence module private ([`a92bb2c`](https://github.com/MartinBernstorff/iterpy/commit/a92bb2ca7b222a883d7836eab7a6eae0e71b21f7))

* dev: add cruft as dependency ([`472b240`](https://github.com/MartinBernstorff/iterpy/commit/472b240f82dd6bd0e9d8474442e5cf3ff533bfb2))

* tests: update import ([`3e76bef`](https://github.com/MartinBernstorff/iterpy/commit/3e76beff52bfd637952ca1d394cda182397d0f92))

* dev: make sequence module private ([`387fbbc`](https://github.com/MartinBernstorff/iterpy/commit/387fbbce62e77be021b8557904dcc1600fb98f75))


## v0.7.0 (2023-10-27)

### Ci

* ci: remove .rej devcontainer ([`a6489e9`](https://github.com/MartinBernstorff/iterpy/commit/a6489e987b3be7adbf74e8ceb07f2cef19c2768c))

* ci: more cruft ([`e5d58e5`](https://github.com/MartinBernstorff/iterpy/commit/e5d58e521071faa75c458f7e1ccd9dafc99be29a))

* ci: update cruft ([`d25bdc8`](https://github.com/MartinBernstorff/iterpy/commit/d25bdc870e654781ad3a1f8ad801094a69dafca6))

### Feature

* feat: bump version ([`fda239c`](https://github.com/MartinBernstorff/iterpy/commit/fda239cbd70c79e5b504048370e50b8137a89952))

### Refactor

* refactor: rename group attrs to key/value ([`b2554d7`](https://github.com/MartinBernstorff/iterpy/commit/b2554d7abfed928e3b86a6b1a06127a53056a380))

### Unknown

* Merge pull request #19 from MartinBernstorff/mb/fundamental-frog

refactor: rename group attrs to key/value ([`9e0062c`](https://github.com/MartinBernstorff/iterpy/commit/9e0062c6d9b4ed6384db6930a5e27fc4c1e7d2ee))

* Update README.md ([`4c0c10d`](https://github.com/MartinBernstorff/iterpy/commit/4c0c10d5adaeedcee8bf8438062d3e259e2c05e0))

* Merge pull request #18 from MartinBernstorff/MartinBernstorff-patch-1

Update README.md ([`d7c5737`](https://github.com/MartinBernstorff/iterpy/commit/d7c573739f56f96a19a43e5d8f9c3b3a79083670))

* Update README.md ([`22eaf22`](https://github.com/MartinBernstorff/iterpy/commit/22eaf2237ee3e06e7b7980694028aee70d2038b5))

* Merge pull request #17 from MartinBernstorff/mb/bright-echidna

ci: update cruft ([`0de85c7`](https://github.com/MartinBernstorff/iterpy/commit/0de85c7873a9ffc5346afcabc519a083d7b0ac0f))


## v0.6.0 (2023-10-26)

### Feature

* feat: add python 3.10 compatability ([`9f1ba34`](https://github.com/MartinBernstorff/iterpy/commit/9f1ba34b66e8cef86cf2d4312e12ede00f2c6c69))

### Unknown

* Update README.md ([`880ddbb`](https://github.com/MartinBernstorff/iterpy/commit/880ddbb36ea58f588982991d13090fa0f75d5c12))

* Update README.md ([`74b82d7`](https://github.com/MartinBernstorff/iterpy/commit/74b82d78b28a739bf90afb1f72a3450b41de29fb))

* Update README.md ([`f6e1506`](https://github.com/MartinBernstorff/iterpy/commit/f6e15068b32cc224abe47eca5114ef377cc29df1))

* Merge pull request #16 from MartinBernstorff/mb/add_python_versions

feat: add python 3.10 compatibility ([`3c34c66`](https://github.com/MartinBernstorff/iterpy/commit/3c34c66ce26dba78edec5481a63d9a5a73c34a95))


## v0.5.0 (2023-10-26)

### Feature

* feat: upgrade version ([`a941cf5`](https://github.com/MartinBernstorff/iterpy/commit/a941cf5dd5bd19258e8d9a6a612dfad5635d698c))

### Refactor

* refactor: rename imports ([`cff61e7`](https://github.com/MartinBernstorff/iterpy/commit/cff61e715e2388c58d5b06a3d78e8324a87f5836))

### Unknown

* Merge pull request #15 from MartinBernstorff/mb/rename_to_functionalpy

refactor: rename to functionalpy ([`4fdc259`](https://github.com/MartinBernstorff/iterpy/commit/4fdc25969e6d3420e763e82ee528b7f44eedafd7))

* Merge branch &#39;main&#39; into mb/rename_to_functionalpy ([`02e7d9c`](https://github.com/MartinBernstorff/iterpy/commit/02e7d9cc060c6ef3abfae597ff034889a050de91))


## v0.4.0 (2023-10-26)

### Ci

* ci: cache in devcontainer.json ([`1ab0332`](https://github.com/MartinBernstorff/iterpy/commit/1ab0332cc58980848a64f3721eaae5a37a7382ad))

* ci: lowercase cache repo URL for devcontainer ([`f83cb16`](https://github.com/MartinBernstorff/iterpy/commit/f83cb16c07cfe0821c7981cac2a9b976d8086a5e))

### Feature

* feat: rename package ([`c67aba4`](https://github.com/MartinBernstorff/iterpy/commit/c67aba47538655e20e47c230a1dce9c2a1f31b56))

* feat: add makefile extension to devcontainer ([`0dccc0b`](https://github.com/MartinBernstorff/iterpy/commit/0dccc0bcc676397f494e0adfc548a553baab2809))

* feat: rename repo ([`e8086e8`](https://github.com/MartinBernstorff/iterpy/commit/e8086e81ab4b0a12ac9a72617c298626556b1b8e))

### Refactor

* refactor: rename to functionalpy ([`f02f425`](https://github.com/MartinBernstorff/iterpy/commit/f02f425684b33e5c7206cf29d5fb5dbdef5d2c67))

### Unknown

* Merge pull request #14 from MartinBernstorff/mb/unfortunate-whale

feat: lowercase cache ([`bab3d8b`](https://github.com/MartinBernstorff/iterpy/commit/bab3d8bed2e1eeac5adc548ca7bf89a8c5e6e6fb))

* misc. ([`73fcab8`](https://github.com/MartinBernstorff/iterpy/commit/73fcab877d16ee25b3fec5e8ae804cceb996c92a))

* Merge branch &#39;main&#39; of https://github.com/MartinBernstorff/FunctionalPython ([`02128f5`](https://github.com/MartinBernstorff/iterpy/commit/02128f52ab5ee149591439e66825800537b1214c))


## v0.3.0 (2023-10-26)

### Ci

* ci: update devcontainer cache ([`86af8b9`](https://github.com/MartinBernstorff/iterpy/commit/86af8b9687d87ab7748132881c8a0cb49e2568db))

* ci: add semantic release info ([`6b90180`](https://github.com/MartinBernstorff/iterpy/commit/6b90180652c5587cc7c0e4376f5fcaf12696e14d))

### Documentation

* docs: update readme ([`f44cb2c`](https://github.com/MartinBernstorff/iterpy/commit/f44cb2c814f0834eb992ec12f10732d09fd68316))

### Feature

* feat: add to_set ([`abe7851`](https://github.com/MartinBernstorff/iterpy/commit/abe78515a30255495c372f60cd1241327134d5ae))

* feat: add to_tuple ([`efc452d`](https://github.com/MartinBernstorff/iterpy/commit/efc452dce177f957cbf7366d8ebe308247a92f45))

* feat: allow import directly from FunctionalPython ([`2547f4b`](https://github.com/MartinBernstorff/iterpy/commit/2547f4bb9b48204888948d37b1ebad85fa176abb))

* feat: bump ([`4d01bc2`](https://github.com/MartinBernstorff/iterpy/commit/4d01bc2bb60e049f13a16b53245953b58b616bdf))

### Unknown

* Merge pull request #13 from MartinBernstorff/mb/noisy-meadowlark

ci: update devcontainer cache ([`78d5e5c`](https://github.com/MartinBernstorff/iterpy/commit/78d5e5cd4d0bbbf0ee7dbe9f3507d4f73c9f163b))

* Update README.md ([`d982d45`](https://github.com/MartinBernstorff/iterpy/commit/d982d453d680d760740632acd1b1c4baaf9314a4))

* Merge pull request #12 from MartinBernstorff/mb/elated-wolf

ci: add semantic release info ([`6943c5a`](https://github.com/MartinBernstorff/iterpy/commit/6943c5ad9d5ad0953b7128807d9723e4461bc231))


## v0.2.0 (2023-10-26)

### Feature

* feat: update version ([`86ac675`](https://github.com/MartinBernstorff/iterpy/commit/86ac6754d4c8fee54359bb8da20ff43b41c144e4))

### Unknown

* Merge pull request #11 from MartinBernstorff/mb/elated-wolf

feat: update version ([`a1f5771`](https://github.com/MartinBernstorff/iterpy/commit/a1f5771ee4512a148c2dd42f188884b6cff0b5b0))


## v0.1.0 (2023-10-26)

### Chore

* chore: formatting and cleanup ([`437ccf9`](https://github.com/MartinBernstorff/iterpy/commit/437ccf9407e5d811fd409453421feb45ca088b0e))

### Ci

* ci: run release after tests ([`42bf7b5`](https://github.com/MartinBernstorff/iterpy/commit/42bf7b53cf2b5467644043f6ff8a2767cf00ad34))

* ci: add release workflow ([`c0dfaf3`](https://github.com/MartinBernstorff/iterpy/commit/c0dfaf38d31d9b6539718eec2ab053273f655d82))

* ci: fix tests ([`8ea9741`](https://github.com/MartinBernstorff/iterpy/commit/8ea9741be519dc9a5074d5f8735870c3ff89850c))

### Documentation

* docs: shorter import ([`826fb0c`](https://github.com/MartinBernstorff/iterpy/commit/826fb0c435a3283d31ef5316b2018d3544096304))

### Feature

* feat: first useage of groupby ([`6f36645`](https://github.com/MartinBernstorff/iterpy/commit/6f36645b81d9e673c68ea086b8244ed498ecc6d4))

### Fix

* fix: use lowercase repository ([`aca7cc3`](https://github.com/MartinBernstorff/iterpy/commit/aca7cc3bc8ff205e85484225884933a29a7818e7))

### Refactor

* refactor: rename var ([`4ca26ca`](https://github.com/MartinBernstorff/iterpy/commit/4ca26cab4dd85dec3af1c27994df609355e7ae3a))

* refactor: split out calculations into functions ([`6ced6db`](https://github.com/MartinBernstorff/iterpy/commit/6ced6dbc7686dd1a26afd684f3c81c35ebd1aad5))

### Unknown

* Merge pull request #10 from MartinBernstorff/mb/bold-fly

ci: run release after tests ([`f603afd`](https://github.com/MartinBernstorff/iterpy/commit/f603afd07e32d73b6acaecb069bf8626bebf1b5f))

* Merge pull request #9 from MartinBernstorff/mb/elated-wolf

dev: add permissions for docker container push ([`85fb3e9`](https://github.com/MartinBernstorff/iterpy/commit/85fb3e9214c1761e7d153e033eb2ae1c836e3966))

* dev: add permissions for docker container push ([`672d0f4`](https://github.com/MartinBernstorff/iterpy/commit/672d0f4a8face720a6c001f5afd492ba32d4cef0))

* Merge pull request #8 from MartinBernstorff/mb/energetic-whippet

ci: add release workflow ([`18c41c5`](https://github.com/MartinBernstorff/iterpy/commit/18c41c529cd53cc9683bd8f9c3627f1a4eb8ba15))

* Merge pull request #7 from MartinBernstorff/mb/brainy-jaguar

ci: fix tests ([`58b9ff4`](https://github.com/MartinBernstorff/iterpy/commit/58b9ff4f10b9eaf5294e274eb4180144cf83b2c1))

* Merge pull request #6 from MartinBernstorff/mb/migrate_to_nimble

init: use new template ([`7511e27`](https://github.com/MartinBernstorff/iterpy/commit/7511e27c981395cde78632dcff951401c718f07f))

* dev: more robust PR ordering ([`2d6591a`](https://github.com/MartinBernstorff/iterpy/commit/2d6591a093d1e447f94a5965f51b6bb00771326a))

* init: use new template ([`e72610d`](https://github.com/MartinBernstorff/iterpy/commit/e72610d3cfbec454d3c0fdf9e13cf539919eec5d))

* Merge pull request #5 from MartinBernstorff/dependabot/pip/pyright-1.1.332

deps:(deps-dev): bump pyright from 1.1.331 to 1.1.332 ([`109af80`](https://github.com/MartinBernstorff/iterpy/commit/109af80045ae6ef51ccbc749b16ff71180e09efc))

* deps:(deps-dev): bump pyright from 1.1.331 to 1.1.332

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.331 to 1.1.332.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.331...v1.1.332)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`893a661`](https://github.com/MartinBernstorff/iterpy/commit/893a661dc2b3932211b9e23c856a58d73dccdb47))

* Merge pull request #4 from MartinBernstorff/dependabot/pip/pyright-1.1.331

deps:(deps-dev): bump pyright from 1.1.330.post0 to 1.1.331 ([`e385895`](https://github.com/MartinBernstorff/iterpy/commit/e385895e3d74a26f43f39821ddf8347d2e47e51c))

* deps:(deps-dev): bump pyright from 1.1.330.post0 to 1.1.331

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.330.post0 to 1.1.331.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.330.post0...v1.1.331)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`26e3e3c`](https://github.com/MartinBernstorff/iterpy/commit/26e3e3c1538fbb5f275fe3404aa166ee66f19664))

* Merge pull request #3 from MartinBernstorff/dependabot/pip/pyright-1.1.330.post0

deps:(deps-dev): bump pyright from 1.1.329 to 1.1.330.post0 ([`dab9be5`](https://github.com/MartinBernstorff/iterpy/commit/dab9be549993764afedea2be5e12438b15a7a88d))

* deps:(deps-dev): bump pyright from 1.1.329 to 1.1.330.post0

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.329 to 1.1.330.post0.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.329...v1.1.330.post0)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`3a6b6ec`](https://github.com/MartinBernstorff/iterpy/commit/3a6b6ec23cd6ce6db6850280214592e0b40f5c6f))

* misc. ([`4b72d8d`](https://github.com/MartinBernstorff/iterpy/commit/4b72d8dbc20187f408ada82ea27fe76562eaee98))

* misc. ([`0c94c86`](https://github.com/MartinBernstorff/iterpy/commit/0c94c860a963f7a83834da4fc06079bbe6e74783))

* formatting ([`fd30295`](https://github.com/MartinBernstorff/iterpy/commit/fd302950c9778f98cea0bfd7d516a5e6cd3a6609))

* formatting ([`4438496`](https://github.com/MartinBernstorff/iterpy/commit/443849672dbb9dd860e10799d79a5293fe0bcd75))

* misc ([`6ec5b26`](https://github.com/MartinBernstorff/iterpy/commit/6ec5b26ec2d187b4653193a36a771dde58892061))

* misc. ([`186e0ce`](https://github.com/MartinBernstorff/iterpy/commit/186e0ce49758658d3b0815555d6e501a3a5f4404))

* formatting ([`4a6083d`](https://github.com/MartinBernstorff/iterpy/commit/4a6083de5949c159b87e50042c7156c3c5b432a5))

* formatting ([`49403ed`](https://github.com/MartinBernstorff/iterpy/commit/49403ed7499055d2d49e61a40a76fa8584d209d1))

* Merge pull request #2 from MartinBernstorff/dependabot/pip/pyright-1.1.329

deps:(deps-dev): bump pyright from 1.1.305 to 1.1.329 ([`f416239`](https://github.com/MartinBernstorff/iterpy/commit/f4162398f8e68dba8f1bba0e5c6486ebe26c3b28))

* Merge pull request #1 from MartinBernstorff/dependabot/pip/invoke-2.2.0

deps:(deps-dev): bump invoke from 2.1.1 to 2.2.0 ([`27247bd`](https://github.com/MartinBernstorff/iterpy/commit/27247bdc154d4a60cb7580d51f608ca5bb685489))

* deps:(deps-dev): bump pyright from 1.1.305 to 1.1.329

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.305 to 1.1.329.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.305...v1.1.329)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`5fa913e`](https://github.com/MartinBernstorff/iterpy/commit/5fa913edba118c39b5233e8cd570b23067e544ee))

* deps:(deps-dev): bump invoke from 2.1.1 to 2.2.0

Bumps [invoke](https://github.com/pyinvoke/invoke) from 2.1.1 to 2.2.0.
- [Commits](https://github.com/pyinvoke/invoke/compare/2.1.1...2.2.0)

---
updated-dependencies:
- dependency-name: invoke
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`8c05b7e`](https://github.com/MartinBernstorff/iterpy/commit/8c05b7eb0496f970d271fb142f6f59d2b8209cff))

* misc. ([`f21b194`](https://github.com/MartinBernstorff/iterpy/commit/f21b194164f03cb782e63081a2fc5e0c5f38ac08))

* Init ([`bb554f4`](https://github.com/MartinBernstorff/iterpy/commit/bb554f404d3ad1609a99c23f63dfb4f8bb9a34a9))
